@@ -58,6 +58,20 @@ def test_quit_pretrigger(nick):
     assert pretrigger.sender is None
 
 
+def test_join_pretrigger(nick):
+    line = ':Foo!foo@example.com JOIN #Sopel'
+    pretrigger = PreTrigger(nick, line)
+    assert pretrigger.tags == {}
+    assert pretrigger.hostmask == 'Foo!foo@example.com'
+    assert pretrigger.line == line
+    assert pretrigger.args == ['#Sopel']
+    assert pretrigger.event == 'JOIN'
+    assert pretrigger.nick == Identifier('Foo')
+    assert pretrigger.user == 'foo'
+    assert pretrigger.host == 'example.com'
+    assert pretrigger.sender == Identifier('#Sopel')
+
+
 def test_tags_pretrigger(nick):
     line = '@foo=bar;baz;sopel.chat/special=value :Foo!foo@example.com PRIVMSG #Sopel :Hello, world'
     pretrigger = PreTrigger(nick, line)
@@ -126,7 +140,49 @@ def test_ctcp_data_pretrigger(nick):
     assert pretrigger.sender == Identifier('Foo')
 
 
-def test_intents_trigger(nick):
+def test_ircv3_extended_join_pretrigger(nick):
+    line = ':Foo!foo@example.com JOIN #Sopel bar :Real Name'
+    pretrigger = PreTrigger(nick, line)
+    assert pretrigger.tags == {'account': 'bar'}
+    assert pretrigger.hostmask == 'Foo!foo@example.com'
+    assert pretrigger.line == line
+    assert pretrigger.args == ['#Sopel', 'bar', 'Real Name']
+    assert pretrigger.event == 'JOIN'
+    assert pretrigger.nick == Identifier('Foo')
+    assert pretrigger.user == 'foo'
+    assert pretrigger.host == 'example.com'
+    assert pretrigger.sender == Identifier('#Sopel')
+
+
+def test_ircv3_extended_join_trigger(nick):
+    line = ':Foo!foo@example.com JOIN #Sopel bar :Real Name'
+    pretrigger = PreTrigger(nick, line)
+
+    config = MockConfig()
+    config.core.owner_account = 'bar'
+
+    fakematch = re.match('.*', line)
+
+    trigger = Trigger(config, pretrigger, fakematch)
+    assert trigger.sender == '#Sopel'
+    assert trigger.raw == line
+    assert trigger.is_privmsg is False
+    assert trigger.hostmask == 'Foo!foo@example.com'
+    assert trigger.user == 'foo'
+    assert trigger.nick == Identifier('Foo')
+    assert trigger.host == 'example.com'
+    assert trigger.event == 'JOIN'
+    assert trigger.match == fakematch
+    assert trigger.group == fakematch.group
+    assert trigger.groups == fakematch.groups
+    assert trigger.args == ['#Sopel', 'bar', 'Real Name']
+    assert trigger.account == 'bar'
+    assert trigger.tags == {'account': 'bar'}
+    assert trigger.owner is True
+    assert trigger.admin is True
+
+
+def test_ircv3_intents_trigger(nick):
     line = '@intent=ACTION :Foo!foo@example.com PRIVMSG #Sopel :Hello, world'
     pretrigger = PreTrigger(nick, line)
 
@@ -148,11 +204,13 @@ def test_intents_trigger(nick):
     assert trigger.match == fakematch
     assert trigger.group == fakematch.group
     assert trigger.groups == fakematch.groups
+    assert trigger.groupdict == fakematch.groupdict
     assert trigger.args == ['#Sopel', 'Hello, world']
     assert trigger.tags == {'intent': 'ACTION'}
     assert trigger.admin is True
     assert trigger.owner is True
 
+
 def test_ircv3_account_tag_trigger(nick):
     line = '@account=Foo :Nick_Is_Not_Foo!foo@example.com PRIVMSG #Sopel :Hello, world'
     pretrigger = PreTrigger(nick, line)
@@ -167,6 +225,7 @@ def test_ircv3_account_tag_trigger(nick):
     assert trigger.admin is True
     assert trigger.owner is True
 
+
 def test_ircv3_server_time_trigger(nick):
     line = '@time=2016-01-09T03:15:42.000Z :Foo!foo@example.com PRIVMSG #Sopel :Hello, world'
     pretrigger = PreTrigger(nick, line)
